from distutils.core import setup

setup(
    name='logcolor2',
    version='0.1.5',
    author='Whilliam sun',
    author_email='syw1894@163.com',
    packages=['logcolor2'],
    url='http://pypi.python.org/pypi/log_color2/',
    license='LICENSE.txt',
    description='test',
    #long_description=open('README.md').read(),
)
